@@ -124,12 +124,14 @@ sub send {
 			print Dumper($request);
 			print Dumper($res);
 		} elsif ($self->{request_errors}) {
-			# I dont think printing content has ever given useful information
-			croak "Request error: HTTP ".$res->status_line .", Content: $res->{_content}";
+			#Should printing content be the default? is it always a JSON hash?
+			#croak "Request error: HTTP ".$res->status_line .", Content: $res->{_content}";
+			die "Request error: HTTP ".$res->status_line .", Content: $res->{_content}";
 		} else {
 			#croak sprintf("Request error: HTTP %s last token: %s time: %s", $res->status_line, $self->{last_token}, time);
 			#croak sprintf("Request error: HTTP %s", $res->status_line);
 			die sprintf("Request error: HTTP %s\n", $res->status_line);
+			#die $res->{_content};
 		}
     }
 }
